.. easy_io documentation master file

Welcome to easy_io's documentation!
===================================

`easy_io` offers a lightweight file IO abstraction with pluggable backends and
format handlers.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   overview
   quickstart

.. toctree::
   :maxdepth: 2
   :caption: How-To Guides

   howto

.. toctree::
   :maxdepth: 2
   :caption: Reference

   reference/backends
   reference/handlers
   reference/utils
   reference/test_utils

.. toctree::
   :maxdepth: 1
   :caption: Project

   changelog
